# Pull Request

## Description
<!-- Provide a clear and concise description of what this PR does -->

## Type of Change
<!-- Mark the relevant option with an [x] -->

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Performance improvement
- [ ] Code refactoring
- [ ] Dependency update
- [ ] CI/CD or tooling change

## Motivation and Context
<!-- Why is this change required? What problem does it solve? -->
<!-- If it fixes an open issue, please link to the issue here -->

Fixes #(issue)

## Changes Made
<!-- Describe the changes in detail -->

-
-
-

## Testing
<!-- Describe the tests you ran to verify your changes -->
<!-- Provide instructions so reviewers can reproduce -->

- [ ] Unit tests added/updated
- [ ] Integration tests added/updated
- [ ] Manual testing performed
- [ ] All existing tests pass

### Test Configuration
<!-- If applicable, describe your test configuration -->
- **Python version:**
- **OS:**
- **LLM provider tested:** (e.g., OpenAI, Anthropic, local model)

## Checklist
<!-- Mark completed items with an [x] -->
- [ ] Code is self-documenting with clear comments
- [ ] Added type hints and docstrings
- [ ] Updated documentation
- [ ] No dead/debug code
- [ ] Robust error handling
- [ ] No breaking changes (or documented if yes)
- [ ] Built on agreed direction from issue discussion

## Performance Impact
<!-- Describe any performance implications of your changes -->

- [ ] No performance impact
- [ ] Performance improved
- [ ] Performance degraded (explain why this trade-off is acceptable)

## Breaking Changes
<!-- If this PR introduces breaking changes, describe them here -->
<!-- Include migration guide if applicable -->

## Additional Notes
<!-- Add any other context about the PR here -->
